@@ -26,3 +26,18 @@ test_that("membership.fakeCommunities() functionality", {
 	expect_equal(length(membership.fakeCommunities(leidenComm)), 100)
 })
 
+test_that("find_partition() functionality", {
+    membership = find_partition_with_rep(exampleGraph, igraph::E(exampleGraph)$weight, nrep = 5)
+    expect_equal(length(membership), 100)
+})
+
+
+test_that("find_partition_with_rep() functionality", {
+    set.seed(42)
+    membership1 = find_partition_with_rep(exampleGraph, igraph::E(exampleGraph)$weight, nrep = 5)
+    set.seed(42)
+    membership2 = find_partition_with_rep(exampleGraph, igraph::E(exampleGraph)$weight, nrep = 5)
+    expect_true(identical(membership1, membership2))
+    expect_equal(length(membership1), 100)
+})
+
